<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
    xmlns="http://www.utc.fr/ics/hdoc/xhtml"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform" >
    
    <xsl:output method="xml" indent="yes"/>
    
    <!-- Fetch the beginning of the document -->
    <xsl:template match="latex">
        <html xmlns="http://www.utc.fr/ics/hdoc/xhtml">
            <!-- Head part of the document -->
            <head>
                <!-- Find the different document's metadata-->
                <title><xsl:value-of select="title"/></title>
                <meta charset="utf-8"/>
                <meta name="generator" content="HdocConverter/LaTeX"/>
                <!-- Apply templates to find document's metadata-->
                <xsl:apply-templates select="author"></xsl:apply-templates>
                <xsl:apply-templates select="date"></xsl:apply-templates>
            </head>
            <!-- End Head part of the document -->
            
            <!-- Body part of the document -->
            <body>
                <!-- Search for main sections -->
                    <xsl:apply-templates select="document"></xsl:apply-templates>
            </body>
            <!-- End of the body part of the document-->
        </html>
    </xsl:template>
    
    <!-- Finding the metadata corresponding to the author of the document-->
    <xsl:template match="author">
        <meta name="author" content="{.}"/>
    </xsl:template>
    
    <!-- Finding the metadata corresponding to the date of creation of the document -->
    <xsl:template match="date">
        <meta name="date" content="{.}" />
    </xsl:template>
    
    <!-- Finding the metadata corresponding to the date of creation of the document -->
    <xsl:template match="document">
        <xsl:apply-templates/>
    </xsl:template>
    
    <!-- Converting chapters into hdoc section -->
    <xsl:template match="chapter">
        <section>
            <header>
                <h1><xsl:value-of select="title"/></h1>
            </header>
            <xsl:for-each select="section | subsection | subsubsection | paragraph | subparagraph | tabular | itemize | enumerate | description | includegraphics | text">
                <xsl:apply-templates select="."></xsl:apply-templates>
            </xsl:for-each>
        </section>
    </xsl:template>
    
    <!-- Converting latex sections into hdoc sections -->
    <xsl:template match="section">
        <section>
            <header>
                <h1><xsl:value-of select="title"/></h1>
            </header>
            <xsl:for-each select="subsection | subsubsection | paragraph | subparagraph | tabular | itemize | enumerate | description | includegraphics | text">
                <xsl:apply-templates select="."></xsl:apply-templates>
            </xsl:for-each>
        </section>
    </xsl:template>
    
    <!-- Converting latex sections into hdoc sections -->
    <xsl:template match="subsection">
        <section>
            <header>
                <h1><xsl:value-of select="title"/></h1>
            </header>
            <xsl:for-each select="subsubsection | paragraph | subparagraph | tabular | itemize | enumerate | description | includegraphics | text">
                <xsl:apply-templates select="."></xsl:apply-templates>
            </xsl:for-each>
        </section>
    </xsl:template>
    
    <!-- Converting latex sections into hdoc sections -->
    <xsl:template match="subsubsection">
        <section>
            <header>
                <h1><xsl:value-of select="title"/></h1>
            </header>
            <xsl:for-each select="paragraph | subparagraph | tabular | itemize | enumerate | description | includegraphics | text">
                <xsl:apply-templates select="."></xsl:apply-templates>
            </xsl:for-each>
        </section>
    </xsl:template>
    
    <xsl:template match="paragraph">
        <section>
            <header>
                <h1><xsl:value-of select="title"/></h1>
            </header>
            <xsl:for-each select="subparagraph | tabular | itemize | enumerate | description | includegraphics | text">
                <xsl:apply-templates select="."></xsl:apply-templates>
            </xsl:for-each>
        </section>
    </xsl:template>
    
    <xsl:template match="subparagraph">
        <section>
            <header>
                <h1><xsl:value-of select="title"/></h1>
            </header>
            <xsl:for-each select="tabular | itemize | enumerate | description | includegraphics | text">
                <xsl:apply-templates select="."></xsl:apply-templates>
            </xsl:for-each>
        </section>
    </xsl:template>
    
    <xsl:template match="text">
        <div><p><xsl:value-of select="."/></p></div>
    </xsl:template>
    
    <xsl:template match="enumerate">
        <div><ul><xsl:for-each select="item"><li><p><xsl:value-of select="."/></p></li></xsl:for-each></ul></div>
    </xsl:template>
    
    <xsl:template match="description">
        <div><ul><xsl:for-each select="item"><li><p><xsl:value-of select="."/></p></li></xsl:for-each></ul></div>
    </xsl:template>
    
    <xsl:template match="itemize">
        <div><ol><xsl:for-each select="item"><li><p><xsl:value-of select="."/></p></li></xsl:for-each></ol></div>
    </xsl:template>
    
    <xsl:template match="includegraphics">
        <div><img src = "ressource/{param}" alt =""/></div>
    </xsl:template>
    
    <xsl:template match="tabular">
        <div>
        <table>
            <xsl:for-each select="tr">
                <tr>
                    <xsl:for-each select="td">
                        <td>
                            <p><xsl:value-of select="."/></p>
                        </td>
                    </xsl:for-each>
                </tr>
            </xsl:for-each>
        </table>
            </div>
    </xsl:template>
    
</xsl:stylesheet>